@@ -1,6 +1,6 @@
 from .activation import HardSwish, HardSigmoid
 from .addition import Add
-from .base import ModuleBase, default_module_settings
+from .base import ModuleBase, default_module_settings, set_module_settings
 from .convolution import Conv2dBN, Conv2dAct
 from .depthwise_separable_conv import DepthwiseSeparableConv2d
 from .focal_loss import FocalLoss
@@ -14,6 +14,6 @@ from .shuffle import ChannelShuffle
 from .ssd_loss import SSDLoss
 from .ssd_predictor import SSDPredictor
 
-__all__ = ['HardSwish', 'HardSigmoid', 'Add', 'ModuleBase', 'default_module_settings', 'Conv2dBN', 'Conv2dAct', 'DepthwiseSeparableConv2d',
+__all__ = ['HardSwish', 'HardSigmoid', 'Add', 'ModuleBase', 'default_module_settings', 'set_module_settings', 'Conv2dBN', 'Conv2dAct', 'DepthwiseSeparableConv2d',
            'FocalLoss', 'LinearAct', 'MBConv', 'PriorBox', 'RetinaPredictor', 'RetinaPriorBox', 'SEBlock',
            'ChannelShuffle', 'SSDLoss', 'SSDPredictor']
